@@ -93,7 +93,6 @@ class Codeplot:
         Main plotting function that dispatches to specific plotting functions based on data type or '_as' parameter.
         """
         try:
-            kwargs.setdefault("id", str(TypeID(prefix="plot")))
             # We force this update to receive latest data from the shared document
             self._update_ykeyvalue()
             
@@ -106,7 +105,8 @@ class Codeplot:
             # to get x and y pos to plot we need consider camera zoom and xy position
 
             
-            shape = self._get_shape(kwargs['id'])
+            shape = self._get_shape(kwargs['id']) if kwargs.get('id') else None
+            kwargs.setdefault("id", str(TypeID(prefix="plot")))
             kwargs.setdefault("title", "Untitled"),
             kwargs.setdefault("width", shape['props']['w'] if shape else 500) 
             kwargs.setdefault("height",  shape['props']['h'] if shape else 250)
@@ -116,8 +116,11 @@ class Codeplot:
             kwargs.setdefault("x_pos", shape['x'] if shape else -camera["x"] + 100)
             kwargs.setdefault("y_pos", shape['y'] if shape else -camera["y"] + 100)
             kwargs.setdefault("page_id", instance["currentPageId"])
+            kwargs.setdefault("ipythonRawCell", None)
+            kwargs.setdefault("ipythonCellId", None)
             kwargs.setdefault("id", str(TypeID(prefix="plot")))
 
+
             shape = {
                     "id": "shape:"+kwargs["id"],
                     "x": kwargs["x_pos"],
@@ -136,68 +139,8 @@ class Codeplot:
                         "metadata": {
                             "isPinned": False,
                             "pythonCallerFrameCodeContext": metacode_line,
-                        },
-                        "createdAt": datetime.datetime.utcnow().isoformat() + "Z"
-                    },
-                    "meta": {},
-                    "type": "codeplot",
-                    "parentId": kwargs["page_id"],
-                    "index": "a1",
-                    "typeName": "shape"
-                }
-
-        
-            await self.set(f"shape:"+kwargs['id'], shape)
-        except Exception as e:
-            raise Exception("Error plotting") from e
-
-
-    async def _plotIPythonCell(self, data, **kwargs) -> None:
-
-        try:
-            kwargs.setdefault("id", str(TypeID(prefix="plot")))
-            # We force this update to receive latest data from the shared document
-            self._update_ykeyvalue()
-
-
-            # last_plot_coords = PatchManager.get_last_plot_xz_coordinates()
-            camera = self._get_current_page_camera()
-            instance = self._get_instance()
-
-            # to get x and y pos to plot we need consider camera zoom and xy position
-            shape = self._get_shape(kwargs['id'])
-
-            
-            kwargs.setdefault("title", "Untitled"),
-            kwargs.setdefault("width", shape['props']['w'] if shape else 500) 
-            kwargs.setdefault("height",  shape['props']['h'] if shape else 250)
-            kwargs.setdefault("rotation",shape['rotation'] if shape else 0)
-            kwargs.setdefault("opacity", shape['opacity'] if shape else 1)
-            kwargs.setdefault("is_locked", shape['isLocked'] if shape else False)
-            kwargs.setdefault("x_pos", shape['x'] if shape else -camera["x"] + 100)
-            kwargs.setdefault("y_pos", shape['y'] if shape else -camera["y"] + 100)
-            kwargs.setdefault("page_id", instance["currentPageId"])
-            kwargs.setdefault("id", str(TypeID(prefix="plot")))
-
-            shape = {
-                    "id": "shape:"+kwargs["id"],
-                    "x": kwargs["x_pos"],
-                    "y": kwargs["y_pos"],
-                    "rotation": kwargs["rotation"],
-                    "opacity": kwargs["opacity"],
-                    "isLocked": kwargs["is_locked"],
-                    "props": {
-                        "w": kwargs["width"],
-                        "h": kwargs["height"],
-                        "id": "shape:"+kwargs["id"],
-                        "title": kwargs["title"],
-                        "type": str(type(data)),
-                        "renderWith": "default",
-                        "mime": data,
-                        "metadata": {
-                            "isPinned": False,
-                            "ipythonRawCell": kwargs["ipython_raw_cell"],
-                            "ipythonCellId": kwargs["ipython_cell_id"],
+                            "ipythonRawCell": kwargs["ipythonRawCell"],
+                            "ipythonCellId": kwargs["ipythonCellId"],
                         },
                         "createdAt": datetime.datetime.utcnow().isoformat() + "Z"
                     },
@@ -208,11 +151,13 @@ class Codeplot:
                     "typeName": "shape"
                 }
             
-
+            
         
             await self.set(f"shape:"+kwargs['id'], shape)
         except Exception as e:
             raise Exception("Error plotting") from e
+
+
        
 class CustomJSONEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -252,6 +197,10 @@ def _get_mime_representations(obj):
 
     representations = {}
 
+    # Here we check if obj is a representation itself
+    if isinstance(obj, dict) and 'text/plain' in obj:
+        return obj
+
     for method_name, mime_type in mime_types.items():
         if hasattr(obj, method_name):
             method = getattr(obj, method_name)
